'''The Nester Module'''

def print_lol(l, indent=False, level=0):
    '''Function that prints a given list recursively with indentation'''
    for item in l:
        if isinstance(item, list):
            print_lol(item, level+1)
        else:
            if indent:
                for tab_stop in range(level):
                    print("\t",end="")
            print(item)
        
